package main

/*
	this parses the command line arguements
	this enables command line options from other packages like 'gui' and 'log'
*/

import (
	"go.wit.com/lib/debugger"
	"go.wit.com/lib/gui/logsettings"
	"go.wit.com/log"
)

var argv args

type args struct {
	TestBuild   *EmptyCmd `arg:"subcommand:build"              help:"try appropriate 'go build'"`
	DebBuild    *EmptyCmd `arg:"subcommand:debian"             help:"build missing .deb packages"`
	MakeInstall *EmptyCmd `arg:"subcommand:install"            help:"run make install in each repo"`
	ListPkgs    *EmptyCmd `arg:"subcommand:list"               help:"list all the packages on mirrors.wit.com"`
	Clone       *EmptyCmd `arg:"subcommand:repomap-clone"      help:"go-clone from a gowebd repomap"`
	Upgrade     *EmptyCmd `arg:"subcommand:upgrade"            help:"apt upgrade packages installed from mirrors.wit.com"`
	RepoMap     string    `arg:"--repomap"                     help:"location of the repomap"`
	Release     bool      `arg:"--release"                     help:"use go-deb --release"`
	DryRun      bool      `arg:"--dry-run"                     help:"only show what would be packaged"`
	Verbose     bool      `arg:"--verbose"                     help:"be loud about it"`
	Recursive   bool      `arg:"--recursive"                   help:"go-clone --recursive"`
	Test        bool      `arg:"--test"                        help:"test build after everything else"`
	WITCOM      bool      `arg:"--witcom"                      help:"add the GPL header"`
	Bash        bool      `arg:"--bash"                        help:"generate bash completion"`
	BashAuto    []string  `arg:"--auto-complete"               help:"does the actual autocompletion"`
}

type EmptyCmd struct {
}

func init() {
	if debugger.ArgDebug() {
		log.Info("cmd line --debugger == true")
		go func() {
			log.Sleep(2)
			debugger.DebugWindow()
		}()
	}

	if debugger.ArgLogger() {
		log.Info("cmd line --loggger == true")
		go func() {
			log.Sleep(4)
			logsettings.LogWindow()
			logsettings.LogWindow()
		}()
	}
}

func (args) Version() string {
	return "wit-test " + VERSION + "    Built on " + BUILDTIME
}
